@@ -1,7 +1,7 @@
 package PERLANCAR::Tree::Examples;
 
-our $DATE = '2016-03-27'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-03-29'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -117,12 +117,7 @@ use base qw(Tree::Example::HashNode);
 
 package # hide from PAUSE
     Tree::Example::ArrayNode;
-use Class::Build::Array::Glob;
-
-has id       => (is=>'rw');
-has level    => (is=>'rw');
-has parent   => (is=>'rw');
-has children => (is=>'rw', glob=>1);
+use Tree::Object::Array::Glob qw(id level);
 
 package # hide from PAUSE
     Tree::Example::ArrayNode::Sub1;
@@ -147,7 +142,7 @@ PERLANCAR::Tree::Examples - Generate sample tree object
 
 =head1 VERSION
 
-This document describes version 0.02 of PERLANCAR::Tree::Examples (from Perl distribution PERLANCAR-Tree-Examples), released on 2016-03-27.
+This document describes version 0.03 of PERLANCAR::Tree::Examples (from Perl distribution PERLANCAR-Tree-Examples), released on 2016-03-29.
 
 =head1 SYNOPSIS
 
